==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Sections/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","˹͡Ѻͧ");
define("_PREVIOUS","˹ҡ͹");
define("_NEXT","˹ҶѴ");
define("_COMESFROM","Ҩҡ");
define("_THEURL","URL Ѻͧ:");
define("_SECWELCOME","Welcome to the Special Sections at");
define("_YOUCANFIND","Here you can find some cool articles not presents in the Home.");
define("_THISISSEC","This is Section");
define("_FOLLOWINGART","Following are the articles published under this section.");
define("_SECRETURN","Return to Sections Index");
define("_TOTALWORDS","total words in this text");
define("_BACKTO","Back to");
define("_SECINDEX","Sections Index");
define("_PAGE","Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Sections/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PRINTER","˹͡Ѻͧ");
define("_PREVIOUS","˹ҡ͹");
define("_NEXT","˹ҶѴ");
define("_COMESFROM","Ҩҡ");
define("_THEURL","URL Ѻͧ:");
define("_SECWELCOME","Welcome to the Special Sections at");
define("_YOUCANFIND","Here you can find some cool articles not presents in the Home.");
define("_THISISSEC","This is Section");
define("_FOLLOWINGART","Following are the articles published under this section.");
define("_SECRETURN","Return to Sections Index");
define("_TOTALWORDS","total words in this text");
define("_BACKTO","Back to");
define("_SECINDEX","Sections Index");
define("_PAGE","Page");

?>
